@@ -51,5 +51,25 @@ __all__ = (
     "HTTPCookie",
     "accept_method",
     "HTTPRequest",
+    "HTTPResponse",
+    "ajax_redirect",
+    "bad_request",
+    "error400",
+    "error401",
+    "error403",
+    "error404",
+    "error405",
+    "error500",
+    "forbidden",
+    "http_error",
+    "internal_error",
+    "json_response",
+    "method_not_allowed",
+    "not_found",
+    "permanent_redirect",
+    "redirect",
+    "see_other",
+    "temporary_redirect",
+    "unauthorized",
 )
-__version__ = "0.1.358"
+__version__ = "3.0.0"
