@@ -2,8 +2,7 @@
 """
 
 from cgi import FieldStorage
-
-from wheezy.http.comp import partition, unquote
+from urllib.parse import unquote
 
 MULTIPART_ENVIRON = {"REQUEST_METHOD": "POST"}
 
@@ -11,7 +10,7 @@ MULTIPART_ENVIRON = {"REQUEST_METHOD": "POST"}
 def parse_qs(qs):
     params = {}
     for field in qs.split("&"):
-        r = partition(field, "=")
+        r = field.partition("=")
         k = r[0]
         v = r[2]
         if "+" in k:
@@ -33,8 +32,8 @@ def parse_qs(qs):
 
 
 def parse_multipart(fp, ctype, clength, encoding):
-    """ Parse multipart/form-data request. Returns
-        a tuple (form, files).
+    """Parse multipart/form-data request. Returns
+    a tuple (form, files).
     """
     fs = FieldStorage(
         fp=fp,
@@ -53,9 +52,9 @@ def parse_multipart(fp, ctype, clength, encoding):
 
 
 def parse_cookie(cookie):
-    """ Parse cookie string and return a dictionary
-        where key is a name of the cookie and value
-        is cookie value.
+    """Parse cookie string and return a dictionary
+    where key is a name of the cookie and value
+    is cookie value.
     """
     return (
         cookie
